summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/slider.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit36a36a5c1015aa0d03f4515c401e907ddb9d6291 (patch)
tree0212ba6d2c749043134005a41f2bd0379619d40f /kalarm/lib/slider.h
parent4c6f8d69e2d1501837affb472c4eb8fec4462240 (diff)
downloadtdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.tar.gz
tdepim-36a36a5c1015aa0d03f4515c401e907ddb9d6291.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdepim@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kalarm/lib/slider.h')
-rw-r--r--kalarm/lib/slider.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kalarm/lib/slider.h b/kalarm/lib/slider.h
index f79ac015..6b72c5ba 100644
--- a/kalarm/lib/slider.h
+++ b/kalarm/lib/slider.h
@@ -41,27 +41,27 @@ class Slider : public TQSlider
TQ_PROPERTY(bool readOnly READ isReadOnly WRITE setReadOnly)
public:
/** Constructor.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit Slider(TQWidget* tqparent = 0, const char* name = 0);
+ explicit Slider(TQWidget* parent = 0, const char* name = 0);
/** Constructor.
* @param orient The orientation of the slider, either TQt::Horizonal or TQt::Vertical.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit Slider(Qt::Orientation orient, TQWidget* tqparent = 0, const char* name = 0);
+ explicit Slider(Qt::Orientation orient, TQWidget* parent = 0, const char* name = 0);
/** Constructor.
* @param minValue The minimum value which the slider can have.
* @param maxValue The maximum value which the slider can have.
* @param pageStep The page step increment.
* @param value The initial value for the slider.
* @param orient The orientation of the slider, either TQt::Horizonal or TQt::Vertical.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
Slider(int minValue, int maxValue, int pageStep, int value, Qt::Orientation orient,
- TQWidget* tqparent = 0, const char* name = 0);
+ TQWidget* parent = 0, const char* name = 0);
/** Returns true if the slider is read only. */
bool isReadOnly() const { return mReadOnly; }
/** Sets whether the slider is read-only for the user.
@@ -41,27 +41,27 @@ class Slider : public TQSlider
public:
/** Constructor.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/
@@ -41,27 +41,27 @@ class Slider : public TQSlider
/** Constructor.
* @param orient The orientation of the slider, either TQt::Horizonal or TQt::Vertical.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/
@@ -41,27 +41,27 @@ class Slider : public TQSlider
* @param value The initial value for the slider.
* @param orient The orientation of the slider, either TQt::Horizonal or TQt::Vertical.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/